@@ -130,7 +130,7 @@ class TooriClient:
         try:
             # Initialize WinDivert injector with address to replace
             init_inbound(self.local_ip)
-        except Exception as e:
+        except (TooriException, WinDivertException) as e:
             self.log(str(e))
             self.disconnect_sio()
             return
@@ -138,7 +138,7 @@ class TooriClient:
         try:
             # Initialize WinDivert sniffer with filter
             init_outbound(self.pkt_filter)
-        except Exception as e:
+        except (TooriException, WinDivertException) as e:
             self.log(str(e))
             self.disconnect_sio()
             uninit_inbound()
